@@ -14,15 +14,16 @@ logging.basicConfig(
 
 
 class VerifyToken:
-    def __init__(self, db: int = 6013, per_defaults=[{}]):
-        self.redis_connect = RedisConnect(db)
-        # 添加默认的权限数据，即 "组件名称":"权限名称" 格式
+    def __init__(self, per_defaults=[{}]):
+        # 通过 per_defaults 添加权限数据，例如：[{'center_name': '组件名称', 'permission_name': '权限名称'},]
         threading.Thread(target=self.add_permission_db,
                          args=(per_defaults, )).start()
         self.uid = ''
+        self.redis_db = os.environ.get('REDIS_DB', 6013)
         self.secret_key = os.environ.get(
             'SECRET_KEY', 'dsfsdfs@#$#@FDgfdgdg325423523525fsdfg*')
         self.expiration = os.environ.get('EXPIRATION', 3600)
+        self.redis_connect = RedisConnect(self.redis_db)
 
     def verify_token(self, request):
         """验证token"""
@@ -32,7 +33,7 @@ class VerifyToken:
             data = s.loads(token.encode('utf-8'))
         except:
             handle_abnormal(
-                message='Token 验证失败',
+                message='来自 {0} 的 Token 验证失败'.format(request.remote_addr),
                 status=401,
             )
         toke_uid = data.get('id')  # token中传来的
@@ -42,7 +43,7 @@ class VerifyToken:
             self.uid = toke_uid.split('--')[0]
             return toke_uid.split('--')[0]  # user_id
         handle_abnormal(
-            message='账户已退出，请重新登录',
+            message='来自 {0} 的账户已退出，需要重新登录'.format(request.remote_addr),
             status=401,
         )
 
@@ -54,13 +55,14 @@ class VerifyToken:
             for per in per_defaults:
                 db = DBConnect(db='universal', collection='permission')
                 # 查询是否已存在
-                find_dict = {'center_name': '', 'permission_name': ''}
+                find_dict = {'center_name': per.center_name,
+                             'permission_name': per.permission_name}
                 sear_permission = db.find_docu(
                     find_dict=find_dict, many=False)
                 if not sear_permission:
                     db.write_one_docu(docu=find_dict)
         except Exception as e:
-            logging.warning('添加权限中心/名称失败， ', str(e))
+            logging.warning('添加权限中心/名称失败', str(e))
 
     def permission_verify(self, center_name_this, permission_name_this) -> int:
         """
@@ -77,7 +79,8 @@ class VerifyToken:
             per_status_this = int(per_set_redis_info)
         if per_status_this == 0:
             handle_abnormal(
-                message='无权限访问',
+                message='无 "{0}-{1}" 的访问权限'.format(
+                    center_name_this, permission_name_this),
                 status=401,
             )
         return per_status_this
